@@ -33,13 +33,16 @@ void CourseSelectDialog::createLayout(QWidget *parent)
 
   connect(pushButtonNext, SIGNAL(clicked()), this, SLOT(next()));
 
+  QDialogButtonBox * buttonBox = new QDialogButtonBox(Qt::Vertical);
+  buttonBox->addButton(pushButtonNext, QDialogButtonBox::ActionRole);
+
   leftLayout = new QVBoxLayout;
   leftLayout->addWidget(lineEditClub);
   leftLayout->addWidget(lineEditCourse);
 
   rightLayout = new QVBoxLayout;
   rightLayout->addStretch();
-  rightLayout->addWidget(pushButtonNext);
+  rightLayout->addWidget(buttonBox);
 
   QHBoxLayout *mainLayout = new QHBoxLayout(parent);
   mainLayout->addLayout(leftLayout);
@@ -96,12 +99,18 @@ void CourseDialog::createLayout(QWidget *parent)
   leftLayout = new QVBoxLayout;
   leftLayout->addWidget(table);
 
+  QDialogButtonBox * buttonBoxUp = new QDialogButtonBox(Qt::Vertical);
+  buttonBoxUp->addButton(pushButtonUp, QDialogButtonBox::ActionRole);
+  buttonBoxUp->addButton(pushButtonDown, QDialogButtonBox::ActionRole);
+  buttonBoxUp->addButton(pushButtonNext, QDialogButtonBox::ActionRole);
+
+  QDialogButtonBox * buttonBoxDown = new QDialogButtonBox(Qt::Vertical);
+  buttonBoxDown->addButton(pushButtonFinish, QDialogButtonBox::ActionRole);
+
   rightLayout = new QVBoxLayout;
-  rightLayout->addWidget(pushButtonUp);
-  rightLayout->addWidget(pushButtonDown);
-  rightLayout->addWidget(pushButtonNext);
+  rightLayout->addWidget(buttonBoxUp);
   rightLayout->addStretch();
-  rightLayout->addWidget(pushButtonFinish);
+  rightLayout->addWidget(buttonBoxDown);
 
   QHBoxLayout *mainLayout = new QHBoxLayout(parent);
   mainLayout->addLayout(leftLayout);
@@ -135,7 +144,7 @@ void CourseDialog::createTable(QWidget *parent)
   table->horizontalHeader()->hide();
   table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
   table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
-  //table->setStyleSheet(ScoreColor::styleSheet());
+  table->setStyleSheet(ScoreStyle::style());
 }
 
 void CourseDialog::init(Course *course)
@@ -154,12 +163,15 @@ void CourseDialog::init(Course *course)
     QTableWidgetItem *len = new QTableWidgetItem("");
 
     QTableWidgetItem *holeNum = new QTableWidgetItem(QString::number(i+1));
-    holeNum->setBackgroundColor(ScoreColor::holeBg());
+    holeNum->setForeground(ScoreColor::holeBg());
+    holeNum->setFlags(Qt::NoItemFlags);
 
     holeNum->setTextAlignment(Qt::AlignCenter);
     par->setTextAlignment(Qt::AlignCenter);
     hcp->setTextAlignment(Qt::AlignCenter);
     len->setTextAlignment(Qt::AlignCenter);
+    // len is not in use - here just to confuse ;(
+    len->setFlags(Qt::NoItemFlags);
     
     if (i < 9) {
       table->setItem(0, i, holeNum);
@@ -174,6 +186,7 @@ void CourseDialog::init(Course *course)
       table->setItem(7, i-9, len);
     }
   }
+  table->setCurrentCell(1, 0);
 }
 
 void CourseDialog::up(void)
