@@ -15,6 +15,7 @@
 #include "main-window.h"
 #include "score-dialog.h"
 #include "course-dialog.h"
+#include "settings-dialog.h"
 #include "stat-model.h"
 #include "xml-dom-parser.h"
 
@@ -28,9 +29,15 @@ QString scoreFileName("score.xml");
 QString scoreFile;
 QString clubFileName("club.xml");
 QString clubFile;
+QString masterFileName("club-master.xml");
+QString masterFile;
 QString logFile("/tmp/scorecard.log");
 QString titleScores("ScoreCard - Scores");
 QString titleCourses("ScoreCard - Courses");
+QString settingsGroup("Settings");
+QString settingsHcp("hcp");
+QString settingsHomeClub("home-club");
+QString settingsDefaultCourses("default-courses");
 
 bool dateLessThan(const Score *s1, const Score *s2)
 {
@@ -102,6 +109,21 @@ Course *MainWindow::findCourse()
     return findCourse(strList[0], strList[1]);
 }
 
+void MainWindow::flushReadOnlyItems()
+{
+    QMutableListIterator<Club *> i(clubList);
+    Club *c;
+
+    while (i.hasNext()) {
+        c = i.next();
+        if (c->isReadOnly()) {
+            qDebug() << "Del:" << c->getName();
+            i.remove();
+        }
+    }
+}
+
+
 MainWindow::MainWindow(QMainWindow *parent): QMainWindow(parent)
 {
   resize(800, 480);
@@ -117,6 +139,8 @@ MainWindow::MainWindow(QMainWindow *parent): QMainWindow(parent)
   setCentralWidget(centralWidget);
 
   loadScoreFile(scoreFile, scoreList);
+  if (conf.defaultCourses == "Yes")
+      loadClubFile(masterFile, clubList, true);
   loadClubFile(clubFile, clubList);
 
   // Sort the scores based on dates
@@ -152,6 +176,7 @@ void MainWindow::loadSettings(void)
 #endif
   scoreFile = dataDir + "/" + scoreFileName;
   clubFile = dataDir + "/" + clubFileName;
+  masterFile = dataDir + "/" + masterFileName;
 
   QDir dir(dataDir);
   if (!dir.exists())
@@ -160,6 +185,30 @@ void MainWindow::loadSettings(void)
       return;
     }
   qDebug() << "Data is at:" + dataDir;
+
+  settings.beginGroup(settingsGroup);
+  conf.hcp = settings.value(settingsHcp);
+  conf.homeClub = settings.value(settingsHomeClub);
+  conf.defaultCourses = settings.value(settingsDefaultCourses);
+  settings.endGroup();
+
+  // Use default courses if no settings for that
+  if (!conf.defaultCourses.isValid())
+      conf.defaultCourses = "Yes";
+
+  qDebug() << "Settings: " << conf.hcp << conf.homeClub << conf.defaultCourses;
+}
+
+void MainWindow::saveSettings(void)
+{
+    settings.beginGroup(settingsGroup);
+    if (conf.hcp.isValid())
+        settings.setValue(settingsHcp, conf.hcp);
+    if (conf.homeClub.isValid())
+        settings.setValue(settingsHomeClub, conf.homeClub);
+    if (conf.defaultCourses.isValid())
+        settings.setValue(settingsDefaultCourses, conf.defaultCourses);
+    settings.endGroup();
 }
 
 void MainWindow::createLayoutList(QWidget *parent)
@@ -217,6 +266,9 @@ void MainWindow::createActions()
     statAction = new QAction(tr("Statistics"), this);
     connect(statAction, SIGNAL(triggered()), this, SLOT(viewStatistics()));
 
+    settingsAction = new QAction(tr("Settings"), this);
+    connect(settingsAction, SIGNAL(triggered()), this, SLOT(viewSettings()));
+
     // Maemo5 style menu filters
     filterGroup = new QActionGroup(this);
     filterGroup->setExclusive(true);
@@ -242,6 +294,7 @@ void MainWindow::createMenus()
     menu->addAction(newScoreAction);
     menu->addAction(newCourseAction);
     menu->addAction(statAction);
+    menu->addAction(settingsAction);
     menu->addActions(filterGroup->actions());
 }
 
@@ -315,7 +368,7 @@ void MainWindow::newCourse()
             if (club) {
                 course = club->getCourse(courseName);
                 if (course) {
-                    qDebug() << "Error: club/course already in the database";
+                    showNote(tr("Club/course already in the database"));
                     return;
                 }
                 else {
@@ -516,7 +569,6 @@ void MainWindow::viewScore(Score * score, Course * course)
     QTableView * table = new QTableView;
     table->showGrid();
     table->setSelectionMode(QAbstractItemView::NoSelection);
-    //table->setStyleSheet(ScoreStyle::headerView());
     table->setStyleSheet(ScoreStyle::style());
     table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
     table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
@@ -586,7 +638,7 @@ void MainWindow::viewStatistics()
   QTableView *table = new QTableView;
   table->showGrid();
   table->setSelectionMode(QAbstractItemView::NoSelection);
-  table->setStyleSheet(ScoreStyle::headerView());
+  table->setStyleSheet(ScoreStyle::style());
   table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
   table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
   table->verticalHeader()->setAutoFillBackground(true);
@@ -609,6 +661,35 @@ void MainWindow::viewStatistics()
   win->show();
 }
 
+void MainWindow::viewSettings()
+{
+    SettingsDialog *dlg = new SettingsDialog(this);
+
+    dlg->init(conf, clubList);
+
+    int result = dlg->exec();
+    if (result) {
+        QString oldValue = conf.defaultCourses.toString();
+        dlg->results(conf);
+        QString newValue = conf.defaultCourses.toString();
+        saveSettings();
+
+        qDebug() << "Settings:" << oldValue << "->" << newValue;
+
+        // Reload club list, or drop r/o courses from list
+        if (oldValue == "Yes" && newValue == "No") {
+            flushReadOnlyItems();
+            courseListModel->update(clubList);
+            list->update();
+        }
+        else if ((oldValue == "No" || oldValue == "") && newValue == "Yes") {
+            loadClubFile(masterFile, clubList, true);
+            courseListModel->update(clubList);
+            list->update();
+        }
+    }
+}
+
 void MainWindow::loadScoreFile(QString &fileName, QList<Score *> &list)
 {
   ScoreXmlHandler handler(list);
@@ -628,12 +709,12 @@ void MainWindow::saveScoreFile(QString &fileName, QList<Score *> &list)
     qWarning() << "Unable to save:" << fileName;
 }
 
-void MainWindow::loadClubFile(QString &fileName, QList<Club *> &list)
+void MainWindow::loadClubFile(QString &fileName, QList<Club *> &list, bool readOnly)
 {
-  ClubXmlHandler handler(list);
+    ClubXmlHandler handler(list);
 
-  if (handler.parse(fileName))
-    qDebug() << "File loaded:" << fileName << " entries:" << list.size();
+    if (handler.parse(fileName, readOnly))
+        qDebug() << "File loaded:" << fileName << " entries:" << list.size();
 }
 
 void MainWindow::saveClubFile(QString &fileName, QList<Club *> &list)
