@@ -17,8 +17,10 @@
 #include <QLabel>
 #include <QActionGroup>
 #include <QXmlDefaultHandler>
+#include <QSettings>
 
 #include "data.h"
+#include "score-common.h"
 #include "table-model.h"
 #include "list-model.h"
 
@@ -33,7 +35,7 @@ public:
   void createListView(QList<Score *> &, QList <Club *> &);
   void updateTitleBar(QString & msg);
   void loadScoreFile(QString &fileName, QList<Score *> &scoreList);
-  void loadClubFile(QString &fileName, QList<Club *> &clubList);
+  void loadClubFile(QString &fileName, QList<Club *> &clubList, bool readOnly = false);
   void saveScoreFile(QString &fileName, QList<Score *> &scoreList);
   void saveClubFile(QString &fileName, QList<Club *> &clubList);
 
@@ -50,16 +52,19 @@ private slots:
   void deleteCourse();
   void editCourse();
   void viewStatistics();
+  void viewSettings();
   void listScores();
   void listCourses();
 
 private:
 
   void loadSettings(void);
+  void saveSettings(void);
   Club * findClub(QString &name);
   Course * findCourse(const QString &clubName, const QString &courseName);
   Course * findCourse();
   Score * findScore(QString & clubName, QString & courseName);
+  void flushReadOnlyItems();
                                
   void showNote(QString msg);
   void getStat(QTextEdit *);
@@ -74,10 +79,8 @@ private:
   ScoreListModel *scoreListModel;
   CourseListModel *courseListModel;
 
-  QAbstractItemModel *tableModel;
   QItemSelectionModel *selectionModel;
 
-  QTableView *table;
   QListView *list;
 
   // Layouts
@@ -86,10 +89,15 @@ private:
   // Menus
   QMenu *menu;
 
+  // Settings
+  QSettings settings;
+  AppSettings conf;
+
   // Actions
   QAction *newScoreAction;
   QAction *newCourseAction;
   QAction *statAction;
+  QAction *settingsAction;
 
   QActionGroup *filterGroup;
   QAction *listScoreAction;
