@@ -8,7 +8,6 @@
 
 #include <QtCore/QtCore>
 #include <QtGui/QtGui>
-#include <QInputContext>
 
 #include "main-window.h"
 
@@ -16,13 +15,9 @@ int main(int argc, char *argv[])
 {
   QApplication app(argc, argv);
 
-#ifdef Q_WS_HILDON
-  QStringList keys = QInputContextFactory::keys();
-  qDebug() << "Input Context Factory keys: " << keys;
-  QInputContext *hildonInputContext=0;
-  hildonInputContext=QInputContextFactory::create("hildon", 0);
-  app.setInputContext(hildonInputContext);
-#endif
+  QCoreApplication::setOrganizationName("garage");
+  QCoreApplication::setOrganizationDomain("maemo.org");
+  QCoreApplication::setApplicationName("ScoreCard");
 
   MainWindow win;
   win.show();
