@@ -31,6 +31,13 @@ QColor colorTotal(Qt::black);
 
 #include <QColor>
 
+class AppSettings {
+public:
+    QVariant hcp;
+    QVariant homeClub;
+    QVariant defaultCourses;
+};
+
 class ScoreColor
 {
  public:
