@@ -14,179 +14,25 @@
 
 QString empty("");
 
-Qt::ItemFlags ScoreTableModel::flags (const QModelIndex &)
+ScoreTableModel::ScoreTableModel(Score * s, Course * c, QObject *parent) 
+    : QAbstractTableModel(parent)
 {
-  return 0;
-}
-
-void ScoreTableModel::setMode(int m)
-{
-  currentMode = m;
-}
-
-int ScoreTableModel::mode(void)
-{
-  return currentMode;
-}
-
-// Assign the 'sList' to internal 'scoreList'. Set the current score
-// to 'currentScore', or to 's'.
-void ScoreTableModel::setScore(QList<Score *> &sList, Score *s)
-{
-  scoreList = sList;
-  if (scoreList.size() > 0) {
-    if (s) {
-      currentScore = scoreList.indexOf(s);
-      if (currentScore == -1)
-	currentScore = 0;
-    }
-    score = scoreList.at(currentScore); // NOTE: assumes non-empty list
-    course = findCourse(score->getClubName(), score->getCourseName());
-  }
-}
-
-void ScoreTableModel::setClub(QList<Club *> &cList)
-{
-  clubList = cList;
-
-  if (clubList.size() > 0)
-    club = clubList.at(0);
-
-  if (club)
-    course = club->getCourse(0);
-}
-
-QString ScoreTableModel::getInfoText()
-{
-  QString str("");
-
-  if (score)
-    str = QString("%1, %2 / [%3/%4]").arg(score->getCourseName()).arg(score->getDate()).arg(currentScore+1).arg(scoreList.count());
-
-  return str;
-}
-
-QString ScoreTableModel::getCountText()
-{
-  QString str = QString("%1/%2").arg(currentScore+1, 2).arg(scoreList.count(), 2);
-  return str;
-}
-
-QString& ScoreTableModel::clubName(void)
-{
-  if (club)
-    return club->getName();
-
-  return empty;
-}
-
-QString& ScoreTableModel::courseName(void)
-{
-  if (course)
-    return course->getName();
-
-  return empty;
-}
-
-Course *ScoreTableModel::findCourse(const QString &clubName, 
-				    const QString &courseName)
-{
-  QListIterator<Club *> i(clubList);
-  Club *c;
-
-  while (i.hasNext()) {
-    c = i.next();
-    if (c->getName() == clubName) {
-      return c->getCourse(courseName);
-    }
-  }
-  return 0;
-}
-
-Club *ScoreTableModel::getClub(void)
-{
-  return club;
-}
-
-Course *ScoreTableModel::getCourse(void)
-{
-  return course;
-}
-
-Score *ScoreTableModel::getScore(void)
-{
-  return score;
-}
-
-void ScoreTableModel::first()
-{
-  if (score && course) {
-    currentScore = 0;
-    score = scoreList.at(currentScore);
-    course = findCourse(score->getClubName(), score->getCourseName());
-    emit dataChanged(createIndex(0, 0), createIndex(ROW_COUNT-1, COL_COUNT-1));
-  }
-}
-
-void ScoreTableModel::last()
-{
-  if (score && course) {
-    currentScore = scoreList.size() - 1;
-    score = scoreList.at(currentScore);
-    course = findCourse(score->getClubName(), score->getCourseName());
-    emit dataChanged(createIndex(0, 0), createIndex(ROW_COUNT-1, COL_COUNT-1));
-  }
-}
-
-void ScoreTableModel::next()
-{
-  if (score && course) {
-    if (currentScore < (scoreList.size() - 1)) {
-      currentScore++;
-      score = scoreList.at(currentScore);
-      course = findCourse(score->getClubName(), score->getCourseName());
-      emit dataChanged(createIndex(0, 0), createIndex(ROW_COUNT-1, COL_COUNT-1));
-    }
-  }
-}
-
-void ScoreTableModel::prev()
-{
-  if (score && course) {
-    if (currentScore > 0) {
-      currentScore--;
-      score = scoreList.at(currentScore);
-      course = findCourse(score->getClubName(), score->getCourseName());
-      emit dataChanged(createIndex(0, 0), createIndex(ROW_COUNT-1, COL_COUNT-1));
-    }
-  }
+    score = s;
+    course = c;
 }
 
 int ScoreTableModel::rowCount(const QModelIndex &) const
 {
-  return 8;
+    return ROWS;
 }
  
 int ScoreTableModel::columnCount(const QModelIndex &) const
 {
-  return 9 + 2; // 2 for in/out and tot columns
-}
-
-QModelIndex ScoreTableModel::index(int row, int column, const QModelIndex &parent) const
-{
-  if (hasIndex(row, column, parent)) {
-    int flag = (parent.column() > 0) ? parent.column() : 0;
-    return createIndex(row, column, flag);
-  }
-  else {
-    return QModelIndex();
-  }
+    return COLS + 2; // 2 for in/out and tot columns
 }
 
 QVariant ScoreTableModel::data(const QModelIndex &index, int role) const
 {
-  // TODO: move away from the stack
-
   if (!index.isValid())
     return QVariant();
 
@@ -206,7 +52,7 @@ QVariant ScoreTableModel::data(const QModelIndex &index, int role) const
   //
   // COLORS
   //
-  if (role == Qt::BackgroundRole) {
+  if (role == Qt::ForegroundRole) {
     // Hole numbers 1-18. All hole nums, in, out and tot cell but not
     // the empty cell.
     if ((row == ROW_HOLE && col != 10) || row == ROW_HOLE_2) {
@@ -269,11 +115,16 @@ QVariant ScoreTableModel::data(const QModelIndex &index, int role) const
   // FONT
   //
   if (role == Qt::FontRole) {
-    if (row == ROW_SCORE_2 && col == (COLS+1)) {
-	QFont font;
-	font.setBold(true);
-	return font;
-    }
+      if (row == ROW_HOLE || row == ROW_HOLE_2) {
+          QFont font;
+          font.setBold(true);
+          return font;
+      }
+      if (row == ROW_SCORE || row == ROW_SCORE_2) {
+          QFont font;
+          font.setBold(true);
+          return font;
+      }
   }
   //
   // NUMBERS
@@ -341,12 +192,6 @@ QVariant ScoreTableModel::data(const QModelIndex &index, int role) const
   return QVariant();
 }
 
-int ScoreTableModel::setItem(int row, int col, int)
-{
-  emit dataChanged(createIndex(row, col), createIndex(row, col));
-  return 1;
-}
-
 QVariant ScoreTableModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
   // Only vertical header -- horizontal is hidden
@@ -355,6 +200,9 @@ QVariant ScoreTableModel::headerData(int section, Qt::Orientation orientation, i
 
   if (role == Qt::DisplayRole) {
     switch(section) {
+    case ROW_HOLE: 
+    case ROW_HOLE_2: 
+      return QString("Hole");
     case ROW_PAR: 
     case ROW_PAR_2: 
       return QString("Par");
@@ -371,3 +219,135 @@ QVariant ScoreTableModel::headerData(int section, Qt::Orientation orientation, i
   return QVariant();
 }
 
+//
+// CourseTableModel
+//
+CourseTableModel::CourseTableModel(Course * c, QObject *parent) 
+    : QAbstractTableModel(parent), course(c)
+{
+}
+
+int CourseTableModel::rowCount(const QModelIndex &) const
+{
+    return ROWS;
+}
+ 
+int CourseTableModel::columnCount(const QModelIndex &) const
+{
+    return COLS + 2;
+}
+
+QVariant CourseTableModel::data(const QModelIndex &index, int role) const
+{
+    if (!index.isValid())
+        return QVariant();
+
+    int row = index.row();
+    int col = index.column();
+
+    //
+    // ALIGNMENT
+    //
+    if (role == Qt::TextAlignmentRole ) {
+        return Qt::AlignCenter;
+    }
+
+    //
+    // FONT
+    //
+    if (role == Qt::FontRole) {
+        if (row == ROW_HOLE || row == ROW_HOLE_2) {
+            QFont font;
+            font.setBold(true);
+            return font;
+        }
+    }
+  //
+  // COLORS
+  //
+  if (role == Qt::ForegroundRole) {
+      // Hole numbers 1-18. All hole nums, in, out and tot cell but not
+      // the empty cell.
+      if ((row == ROW_HOLE && col != 10) || row == ROW_HOLE_2) {
+          QBrush brush(ScoreColor::holeBg());
+          return brush;
+      }
+      return QVariant();
+  }
+    //
+    // NUMBERS
+    //
+    if (role == Qt::DisplayRole) {
+
+        if (col == COLS) {
+            // In/out label
+            if (row == ROW_HOLE)
+                return QString("Out");
+            if (row == ROW_HOLE_2)
+                return QString("In");
+
+            // In/Out for par
+            if (course && row == ROW_PAR)
+                return course->getTotal(TotalOut);
+            if (course && row == ROW_PAR_2)
+                return course->getTotal(TotalIn);
+        }
+        else if (col == (COLS+1)) {
+            // Total label
+            if (row == ROW_HOLE_2)
+                return QString("Tot");
+            // Total score
+            if (course && row == ROW_PAR_2)
+                return course->getTotal(Total);
+        }
+        else {
+            // data cells
+            switch(row) {
+            case ROW_HOLE:
+                return col + 1;
+            case ROW_HOLE_2:
+                return col + 10;
+            case ROW_PAR:
+                if (course)
+                    return course->getPar(col); 
+            case ROW_PAR_2:
+                if (course)
+                    return course->getPar(col + 9); 
+            case ROW_HCP: 
+                if (course)
+                    return course->getHcp(col); 
+            case ROW_HCP_2:
+                if (course)
+                    return course->getHcp(col + 9);
+      }
+    }
+  }
+  return QVariant();
+}
+
+QVariant CourseTableModel::headerData(int section, Qt::Orientation orientation, int role) const
+{
+  // Only vertical header -- horizontal is hidden
+  if (orientation == Qt::Horizontal)
+    return QVariant();
+
+  if (role == Qt::DisplayRole) {
+    switch(section) {
+    case ROW_HOLE: 
+    case ROW_HOLE_2: 
+      return QString("Hole");
+    case ROW_PAR: 
+    case ROW_PAR_2: 
+      return QString("Par");
+    case ROW_HCP: 
+    case ROW_HCP_2: 
+      return QString("HCP");
+    case ROW_LEN: 
+    case ROW_LEN_2: 
+      return QString("Len");
+    }
+    return QVariant();
+  }
+
+  return QVariant();
+}
